#
# spec file for package soundconverter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(GConf\\)|typelib\\(Unity\\)
%define pythons python3
Name:           soundconverter
Version:        4.0.5
Release:        1.4
Summary:        Sound Converter Application for the GNOME Desktop
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://soundconverter.org
Source0:        https://launchpad.net/soundconverter/trunk/%{version}/+download/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-pytest
BuildRequires:  typelib(Gst) = 1.0
BuildRequires:  typelib(GstPbutils) = 1.0
BuildRequires:  typelib(Gtk) = 3.0
Requires:       gstreamer
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-ugly
Suggests:       gstreamer-plugins-bad-orig-addon
Suggests:       gstreamer-plugins-ugly-orig-addon

%description
A sound converter application for the GNOME environment.

It reads anything the GStreamer library can read, and offers writing
to WAV, FLAC, MP3, AAC, and Ogg Vorbis, also with the help of GStreamer.

%lang_package

%prep
%autosetup -p1

%build
%python_build

%install
%python_install

%find_lang %{name}

desktop-file-install \
  --dir %{buildroot}%{_datadir}/applications \
  --add-category X-OutputGeneration \
  --delete-original \
  build/share/applications/%{name}.desktop

rm -f %{buildroot}%{_datadir}/glib-2.0/schemas/gschemas.compiled
rm -rf %{buildroot}/usr/share/doc/soundconverter

%fdupes %{buildroot}%{_prefix}

%check
#%%pytest tests

%files
%license COPYING
%doc README.md NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/glib-2.0/schemas/org.soundconverter.gschema.xml
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-*.egg-info

%files lang -f %{name}.lang

%changelog
* Thu May  9 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.5:
  * appdata: Update appdata
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.4:
  * minor Russian translation fixes
  * tests/test.py, tests/testcases/batch_integration.py,
  * tests/testcases/{integration.py => gui_integration.py},
  * tests/util.py: split integration tests into multiple files
    for batch
  * and gui
  * Update Turkish
  * Fix a typo Without
    space sentence seems as "moreinformation".
  * Add release dates to appdata.xml
  * Using GLib events instead of callbacks, fixed recursion problems
  * Using a signal on Task instead of TaskQueue for task_done
  * soundconverter/interface/filelist.py,
  * soundconverter/interface/ui.py: Optimized filelist progress
    updates
  * soundconverter/gstreamer/discoverer.py,
    tests/testcases/batch.py,
  * tests/testcases/discoverer.py: Not treating images as audio
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.3: bugfix release.
* Thu Jul 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.0.1:
  * Fix events leakage crash during big conversions.
  * Fix UI issue when an encoder is missing, the settings were not working.
  * Fix DATA_PATH from flatpak.
  * Fix a few issues with appstream data
  * Remove empty line in glade, remove warning log.
* Sat Mar 20 2021 antoine.belvire@opensuse.org
- Reduce build set to default python3 flavour: Fix build on
  Tumbleweed.
* Thu Jan  7 2021 ecsos <ecsos@opensuse.org>
- Update to 4.0.0
  See: https://launchpad.net/soundconverter/trunk/4.0.0/+index#
* Sun Oct 25 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 3.0.2.
  * Upstream does not provide an informational log.
  * Refresh spec-file via spec-cleaner and manual optimizations.
  * Remove Only-fetch-profiles-if-GConf-is-still-available.patch.
  * Remove update_desktop_file and outdated design.
* Thu Jun  7 2018 bjorn.lie@gmail.com
- Add Only-fetch-profiles-if-GConf-is-still-available.patch: No
  longer mandate gconf2, also add typelib(GConf) to global requires
  exclude, prevent the gir scanner to add typelib.
* Mon May 21 2018 bjorn.lie@gmail.com
- Update to version 3.0.0:
  + Change GConf to GSettings to store settings.
  + Stop using typefind when adding files, and filter only when
    converting. This is much faster.
  + Actually use --jobs command line to limit the number of jobs.
  + Updated translations.
- Run spec-cleaner, modernize spec.
- Update source url to point to launchpad.
- Drop autoconf and automake BuildRequires and no longer pass
  autoreconf, using properly bootstrapped tarball again.
- Drop conditionals for obsolete versions of openSUSE.
- "Updgrade" gstreamer-plugins-base and gstreamer-plugins-good
  Recommends to Requires. If one wants soundconverter to do
  anything meaningfull, these two are needed.
- Add gstreamer-plugins-bad-orig-addon Suggests (for aac support).
* Sun Feb 26 2017 zaitor@opensuse.org
- Add global __requires_exclude typelib\\(Unity\\), make app
  installable.
* Wed Feb  8 2017 jengelh@inai.de
- Description update
* Thu Jan 19 2017 sor.alexei@meowr.ru
- Update to version 2.9.0~beta2:
  * No changelog available.
- Separate locales to soundconverter-lang.
- Own /usr/share/appdata/ unconditionally.
* Mon Mar 28 2016 mailaender@opensuse.org
- Update to version 2.1.6:
  + Fix: name 'vfs_exists' is not defined.
    (Closes pr:10, thanks Michael)
  + Fix problem when dropping files.
    (Closes lp:1432399, thanks Thibaut & Rüdiger)
* Sat Mar  7 2015 zaitor@opensuse.org
- Update to version 2.1.5:
  + Don't write xing header if target MP3 is in CBR mode
    (lp#1399276).
  + Fix problem when dropping files with special chars.
  + Updated translations.
- Changes from version 1.5.5 to current, please see upstream web.
- Update url and source to new home, and update licencetag to new
  standard.
- Stop building as noarch package, it is not anymore.
* Fri Jul 15 2011 fisiu@opensuse.org
- upstream update to 1.5.4
* Sun Jun 20 2010 vishwin80@googlemail.com
- update to 1.5.3
* Wed Mar 31 2010 vishwin80@googlemail.com
- 1.5.0 alpha1
